bipartite_from_data_frame: two-mode network from a data.frame

View source: R/graphs.R

bipartite_from_data_frameR Documentation

two-mode network from a data.frame

Description

Create a two-mode network from a data.frame

Usage

bipartite_from_data_frame(d, type1, type2, attr = NULL, weighted = TRUE)

Arguments

d

data.frame

type1

column name of mode 1

type2

column name of mode 2

attr

named list of edge attributes

weighted

should a weighted graph be created if multiple edges occur

Details

Vertex identifiers are converted to character, so numeric and factor columns are matched by their values. If weighted = TRUE, multiple edges are merged, their count is stored in the edge attribute weight, numeric edge attributes are summed and other edge attributes keep their first value.

Value

two mode network as igraph object. The vertex attribute type is TRUE for vertices from type1 and FALSE for vertices from type2.

Author(s)

David Schoch

Examples

library(igraph)
edges <- data.frame(mode1 = 1:5, mode2 = letters[1:5])
bipartite_from_data_frame(edges, "mode1", "mode2")

netUtils documentation built on Sept. 30, 2026, 5:10 p.m.