View source: R/lfr_benchmark.R
| sample_lfr | R Documentation |
Generates benchmark networks for clustering tasks with a priori known communities. The algorithm accounts for the heterogeneity in the distributions of node degrees and of community sizes.
sample_lfr(
n,
tau1 = 2,
tau2 = 1,
mu = 0.1,
average_degree,
max_degree,
min_community = NULL,
max_community = NULL,
on = 0,
om = 0,
verbose = FALSE
)
n |
Number of nodes in the created graph. |
tau1 |
Power law exponent for the degree distribution of the created graph. This value must be at least one. |
tau2 |
Power law exponent for the community size distribution in the created graph. This value must be at least one. |
mu |
Fraction of inter-community edges incident to each node. This value must be in the interval 0 to 1. |
average_degree |
Desired average degree of nodes in the created graph. This value must be in the interval (0, n] and is required. |
max_degree |
Maximum degree of nodes in the created graph. This value must be in the interval (0, n] and is required. |
min_community |
Minimum size of communities in the graph. Either both or none of |
max_community |
Maximum size of communities in the graph. Must be at least |
on |
number of overlapping nodes (a non-negative integer not larger than |
om |
number of memberships of the overlapping nodes. Must be at least 2 if |
verbose |
logical. Should progress messages of the generator be printed? |
code adapted from https://github.com/synwalk/synwalk-analysis/tree/master/lfr_generator.
Random numbers are drawn from R's random number generator, so results can be reproduced with set.seed().
an igraph object with two vertex attributes: membership, an integer vector
holding the (first) community of each vertex, and memberships, a list holding
all communities of each vertex (only overlapping vertices have more than one).
A. Lancichinetti, S. Fortunato, and F. Radicchi.(2008) Benchmark graphs for testing community detection algorithms. Physical Review E, 78. arXiv:0805.4770
# Simple Girven-Newman benchmark graphs
g <- sample_lfr(
n = 128, average_degree = 16,
max_degree = 16, mu = 0.1,
min_community = 32, max_community = 32
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.